@@ -3,7 +3,7 @@ from django import template
 
 from simple_translation.middleware import filter_queryset_language
 
-from ..models import EventCategory, EventTitle
+from ..models import EventCategory, Event
 
 
 register = template.Library()
@@ -18,14 +18,13 @@ def get_event_categories():
 @register.assignment_tag(takes_context=True)
 def get_events(context, amount=5):
     """
-    Returns upcoming events.
+    Returns upcoming and currently running events.
 
     :param request: The current request.
     :param amount: The number of events that should be returned.
 
     """
     request = context.get('request')
-    qs = EventTitle.objects.filter(
-        event__is_published=True).order_by('event__start_date')
+    qs = Event.objects.get_visible()
     qs = filter_queryset_language(request, qs)
     return qs[:amount]
